@@ -21,8 +21,11 @@ use utf8;
 use IO::File;
 #use re 'debug';
 
+use Date::Manip::Base;
+use Date::Manip::TZ;
+
 our $VERSION;
-$VERSION='6.31';
+$VERSION='6.32';
 END { undef $VERSION; }
 
 ########################################################################
